summaryrefslogtreecommitdiffstats
path: root/core/java/android/bluetooth/BluetoothDevice.java
diff options
context:
space:
mode:
authorThe Android Open Source Project <initial-contribution@android.com>2009-02-10 15:44:00 -0800
committerThe Android Open Source Project <initial-contribution@android.com>2009-02-10 15:44:00 -0800
commitd24b8183b93e781080b2c16c487e60d51c12da31 (patch)
treefbb89154858984eb8e41556da7e9433040d55cd4 /core/java/android/bluetooth/BluetoothDevice.java
parentf1e484acb594a726fb57ad0ae4cfe902c7f35858 (diff)
downloadframeworks_base-d24b8183b93e781080b2c16c487e60d51c12da31.zip
frameworks_base-d24b8183b93e781080b2c16c487e60d51c12da31.tar.gz
frameworks_base-d24b8183b93e781080b2c16c487e60d51c12da31.tar.bz2
auto import from //branches/cupcake/...@130745
Diffstat (limited to 'core/java/android/bluetooth/BluetoothDevice.java')
-rw-r--r--core/java/android/bluetooth/BluetoothDevice.java97
1 files changed, 36 insertions, 61 deletions
diff --git a/core/java/android/bluetooth/BluetoothDevice.java b/core/java/android/bluetooth/BluetoothDevice.java
index d613e1c..56b231f 100644
--- a/core/java/android/bluetooth/BluetoothDevice.java
+++ b/core/java/android/bluetooth/BluetoothDevice.java
@@ -31,10 +31,15 @@ import java.io.UnsupportedEncodingException;
* @hide
*/
public class BluetoothDevice {
- public static final int MODE_UNKNOWN = -1;
- public static final int MODE_OFF = 0;
- public static final int MODE_CONNECTABLE = 1;
- public static final int MODE_DISCOVERABLE = 2;
+ /** Inquiry scan and page scan are both off.
+ * Device is neither discoverable nor connectable */
+ public static final int SCAN_MODE_NONE = 0;
+ /** Page scan is on, inquiry scan is off.
+ * Device is connectable, but not discoverable */
+ public static final int SCAN_MODE_CONNECTABLE = 1;
+ /** Page scan and inquiry scan are on.
+ * Device is connectable and discoverable */
+ public static final int SCAN_MODE_CONNECTABLE_DISCOVERABLE = 3;
public static final int RESULT_FAILURE = -1;
public static final int RESULT_SUCCESS = 0;
@@ -54,10 +59,10 @@ public class BluetoothDevice {
/** A bond attempt failed because the other side explicilty rejected
* bonding */
public static final int UNBOND_REASON_AUTH_REJECTED = 2;
- /** A bond attempt failed because we cancelled the bonding process */
- public static final int UNBOND_REASON_CANCELLED = 3;
+ /** A bond attempt failed because we canceled the bonding process */
+ public static final int UNBOND_REASON_AUTH_CANCELED = 3;
/** A bond attempt failed because we could not contact the remote device */
- public static final int UNBOND_REASON_AUTH_REMOTE_DEVICE_DOWN = 4;
+ public static final int UNBOND_REASON_REMOTE_DEVICE_DOWN = 4;
/** An existing bond was explicitly revoked */
public static final int UNBOND_REASON_REMOVED = 5;
@@ -174,18 +179,6 @@ public class BluetoothDevice {
return false;
}
- public String getMajorClass() {
- try {
- return mService.getMajorClass();
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
- public String getMinorClass() {
- try {
- return mService.getMinorClass();
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
public String getVersion() {
try {
return mService.getVersion();
@@ -211,15 +204,26 @@ public class BluetoothDevice {
return null;
}
- public int getMode() {
+ /**
+ * Get the current scan mode.
+ * Used to determine if the local device is connectable and/or discoverable
+ * @return Scan mode, one of SCAN_MODE_* or an error code
+ */
+ public int getScanMode() {
try {
- return mService.getMode();
+ return mService.getScanMode();
} catch (RemoteException e) {Log.e(TAG, "", e);}
- return MODE_UNKNOWN;
+ return BluetoothError.ERROR_IPC;
}
- public void setMode(int mode) {
+
+ /**
+ * Set the current scan mode.
+ * Used to make the local device connectable and/or discoverable
+ * @param scanMode One of SCAN_MODE_*
+ */
+ public void setScanMode(int scanMode) {
try {
- mService.setMode(mode);
+ mService.setScanMode(scanMode);
} catch (RemoteException e) {Log.e(TAG, "", e);}
}
@@ -435,24 +439,6 @@ public class BluetoothDevice {
return null;
}
- public String getRemoteAlias(String address) {
- try {
- return mService.getRemoteAlias(address);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
- public boolean setRemoteAlias(String address, String alias) {
- try {
- return mService.setRemoteAlias(address, alias);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return false;
- }
- public boolean clearRemoteAlias(String address) {
- try {
- return mService.clearRemoteAlias(address);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return false;
- }
public String getRemoteVersion(String address) {
try {
return mService.getRemoteVersion(address);
@@ -477,24 +463,6 @@ public class BluetoothDevice {
} catch (RemoteException e) {Log.e(TAG, "", e);}
return null;
}
- public String getRemoteMajorClass(String address) {
- try {
- return mService.getRemoteMajorClass(address);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
- public String getRemoteMinorClass(String address) {
- try {
- return mService.getRemoteMinorClass(address);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
- public String[] getRemoteServiceClasses(String address) {
- try {
- return mService.getRemoteServiceClasses(address);
- } catch (RemoteException e) {Log.e(TAG, "", e);}
- return null;
- }
/**
* Returns the RFCOMM channel associated with the 16-byte UUID on
@@ -512,12 +480,19 @@ public class BluetoothDevice {
return false;
}
+ /**
+ * Get the major, minor and servics classes of a remote device.
+ * These classes are encoded as a 32-bit integer. See BluetoothClass.
+ * @param address remote device
+ * @return 32-bit class suitable for use with BluetoothClass.
+ */
public int getRemoteClass(String address) {
try {
return mService.getRemoteClass(address);
} catch (RemoteException e) {Log.e(TAG, "", e);}
return BluetoothClass.ERROR;
}
+
public byte[] getRemoteFeatures(String address) {
try {
return mService.getRemoteFeatures(address);
@@ -576,8 +551,8 @@ public class BluetoothDevice {
}
- /* Sanity check a bluetooth address, such as "00:43:A8:23:10:F0" */
private static final int ADDRESS_LENGTH = 17;
+ /** Sanity check a bluetooth address, such as "00:43:A8:23:10:F0" */
public static boolean checkBluetoothAddress(String address) {
if (address == null || address.length() != ADDRESS_LENGTH) {
return false;